==> barman-2.0b1.tar.gz: barman-2.0b1/doc/manual/66-about.en.md <==
\newpage

# The Barman project

## Support and sponsor opportunities

Barman is free software, written and maintained by 2ndQuadrant. If you
require support on using Barman, or if you need new features, please
get in touch with 2ndQuadrant. You can sponsor the development of new
features of Barman and PostgreSQL which will be made publicly
available as open source.

For further information, please visit:

- [Barman website] [11]
- [Support section] [12]
- [2ndQuadrant website] [13]
- [FAQs] [14]
- [2ndQuadrant blog] [15]

## Contributing to Barman

2ndQuadrant has a team of software engineers, architects, database
administrators, system administrators, QA engineers, developers and
managers that dedicate their time and expertise to improve Barman's code.
We adopt lean and agile methodologies for software development, and
we believe in the _devops_ culture that allowed us to implement rigorous
testing procedures through cross-functional collaboration.
Every Barman commit is the contribution of multiple individuals, at different
stages of the production pipeline.

Even though this is our preferred way of developing Barman, we gladly
accept patches from external developers, as long as:

- user documentation (tutorial and man pages) is provided;
- source code is properly documented and contains relevant comments;
- code supplied is covered by unit tests;
- no unrelated feature is compromised or broken;
- source code is rebased on the current master branch;
- commits and pull requests are limited to a single feature (multi-feature
patches are hard to test and review);
- changes to the user interface are discussed beforehand with 2ndQuadrant.

We also require that any contributions provide a copyright assignment
and a disclaimer of any work-for-hire ownership claims from the employer
of the developer.

You can use Github's pull requests system for this purpose.

## Authors

In alphabetical order:

- Gabriele Bartolini <gabriele.bartolini@2ndquadrant.it> (project leader)
- Jonathan Battiato <jonathan.battiato@2ndquadrant.it> (QA/testing)
- Stefano Bianucci (developer)
- Giuseppe Broccolo <giuseppe.broccolo@2ndquadrant.it> (QA/testing)
- Giulio Calacoci <giulio.calacoci@2ndquadrant.it> (developer)
- Francesco Canovai <francesco.canovai@2ndquadrant.it> (QA/testing)
- Leonardo Cecchi <leonardo.cecchi@2ndquadrant.it> (developer)
- Gianni Ciolli <gianni.ciolli@2ndquadrant.it> (QA/testing)
- Britt Cole <britt.cole@2ndquadrant.it> (documentation)
- Marco Nenciarini <marco.nenciarini@2ndquadrant.it> (lead developer)
- Rubens Souza <rubens.souza@2ndquadrant.it> (QA/testing)

Past contributors:

- Carlo Ascani

## Links

- [check-barman] [16]: a Nagios plugin for Barman, written by Holger
  Hamann (MIT license)
- [puppet-barman] [17]: Barman module for Puppet (GPL)
- [Tutorial on "How To Back Up, Restore, and Migrate PostgreSQL Databases with Barman on CentOS 7"] [26], by Sadequl Hussain (available on DigitalOcean Community)
- [BarmanAPI] [27]: RESTFul API for Barman, written by Mehmet Emin Karakaş (GPL)

## License and Contributions

Barman is the exclusive property of 2ndQuadrant Italia and its code is
distributed under GNU General Public License 3.

Copyright (C) 2011-2016 [2ndQuadrant.it S.r.l.] [19].

Barman has been partially funded through [4CaaSt] [18], a research
project funded by the European Commission's Seventh Framework
programme.

Contributions to Barman are welcome, and will be listed in the
`AUTHORS` file. 2ndQuadrant Italia requires that any contributions
provide a copyright assignment and a disclaimer of any work-for-hire
ownership claims from the employer of the developer. This lets us make
sure that all of the Barman distribution remains free code. Please
contact info@2ndQuadrant.it for a copy of the relevant Copyright
Assignment Form.

==> barman_2.1.orig.tar.gz: barman-2.1/doc/manual/66-about.en.md <==
\newpage

# The Barman project

## Support and sponsor opportunities

Barman is free software, written and maintained by 2ndQuadrant. If you
require support on using Barman, or if you need new features, please
get in touch with 2ndQuadrant. You can sponsor the development of new
features of Barman and PostgreSQL which will be made publicly
available as open source.

For further information, please visit:

- [Barman website] [11]
- [Support section] [12]
- [2ndQuadrant website] [13]
- [Barman FAQs] [14]
- [2ndQuadrant blog: Barman] [15]

## Contributing to Barman

2ndQuadrant has a team of software engineers, architects, database
administrators, system administrators, QA engineers, developers and
managers that dedicate their time and expertise to improve Barman's code.
We adopt lean and agile methodologies for software development, and
we believe in the _devops_ culture that allowed us to implement rigorous
testing procedures through cross-functional collaboration.
Every Barman commit is the contribution of multiple individuals, at different
stages of the production pipeline.

Even though this is our preferred way of developing Barman, we gladly
accept patches from external developers, as long as:

- user documentation (tutorial and man pages) is provided.
- source code is properly documented and contains relevant comments.
- code supplied is covered by unit tests.
- no unrelated feature is compromised or broken.
- source code is rebased on the current master branch.
- commits and pull requests are limited to a single feature (multi-feature
patches are hard to test and review).
- changes to the user interface are discussed beforehand with 2ndQuadrant.

We also require that any contributions provide a copyright assignment
and a disclaimer of any work-for-hire ownership claims from the employer
of the developer.

You can use Github's pull requests system for this purpose.

## Authors

In alphabetical order:

- Gabriele Bartolini, <gabriele.bartolini@2ndquadrant.it> (project leader)
- Jonathan Battiato, <jonathan.battiato@2ndquadrant.it> (QA/testing)
- Stefano Bianucci, (developer, intern from University of Florence)
- Giuseppe Broccolo, <giuseppe.broccolo@2ndquadrant.it> (QA/testing)
- Giulio Calacoci, <giulio.calacoci@2ndquadrant.it> (developer)
- Francesco Canovai, <francesco.canovai@2ndquadrant.it> (QA/testing)
- Leonardo Cecchi, <leonardo.cecchi@2ndquadrant.it> (developer)
- Gianni Ciolli, <gianni.ciolli@2ndquadrant.it> (QA/testing)
- Britt Cole, <britt.cole@2ndquadrant.it> (documentation)
- Marco Nenciarini, <marco.nenciarini@2ndquadrant.it> (lead developer)
- Rubens Souza, <rubens.souza@2ndquadrant.it> (QA/testing)

Past contributors:

- Carlo Ascani

## Links

- [check-barman] [16]: a Nagios plugin for Barman, written by Holger
  Hamann (MIT license)
- [puppet-barman] [17]: Barman module for Puppet (GPL)
- [Tutorial on "How To Back Up, Restore, and Migrate PostgreSQL Databases with Barman on CentOS 7"] [26], by Sadequl Hussain (available on DigitalOcean Community)
- [BarmanAPI] [27]: RESTFul API for Barman, written by Mehmet Emin Karakaş (GPL)

## License and Contributions

Barman is the property of 2ndQuadrant Italia and its code is
distributed under GNU General Public License 3.

Copyright (C) 2011-2016 [2ndQuadrant.it S.r.l.] [19].

Barman has been partially funded through [4CaaSt] [18], a research
project funded by the European Commission's Seventh Framework
programme.

Contributions to Barman are welcome, and will be listed in the
`AUTHORS` file. 2ndQuadrant Italia requires that any contributions
provide a copyright assignment and a disclaimer of any work-for-hire
ownership claims from the employer of the developer. This lets us make
sure that all of the Barman distribution remains free code. Please
contact info@2ndQuadrant.it for a copy of the relevant Copyright
Assignment Form.
